@@ -1,6 +1,6 @@
 function _aws_cdk_aws_route53recoverycontrol_CfnRoutingControlProps(p) {
 }
-function _aws_cdk_aws_route53recoverycontrol_CfnControlPanelProps(p) {
+function _aws_cdk_aws_route53recoverycontrol_CfnClusterProps(p) {
     if (p == null)
         return;
     visitedObjects.add(p);
@@ -8,7 +8,7 @@ function _aws_cdk_aws_route53recoverycontrol_CfnControlPanelProps(p) {
         require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
     visitedObjects.delete(p);
 }
-function _aws_cdk_aws_route53recoverycontrol_CfnClusterProps(p) {
+function _aws_cdk_aws_route53recoverycontrol_CfnControlPanelProps(p) {
     if (p == null)
         return;
     visitedObjects.add(p);
@@ -57,5 +57,5 @@ function print(name, deprecationMessage) {
 const visitedObjects = new Set();
 class DeprecationError extends Error {
 }
-module.exports = { print, _aws_cdk_aws_route53recoverycontrol_CfnRoutingControlProps, _aws_cdk_aws_route53recoverycontrol_CfnControlPanelProps, _aws_cdk_aws_route53recoverycontrol_CfnClusterProps, _aws_cdk_aws_route53recoverycontrol_CfnRoutingControl, _aws_cdk_aws_route53recoverycontrol_CfnCluster, _aws_cdk_aws_route53recoverycontrol_CfnCluster_ClusterEndpointProperty, _aws_cdk_aws_route53recoverycontrol_CfnControlPanel, _aws_cdk_aws_route53recoverycontrol_CfnSafetyRuleProps, _aws_cdk_aws_route53recoverycontrol_CfnSafetyRule, _aws_cdk_aws_route53recoverycontrol_CfnSafetyRule_AssertionRuleProperty, _aws_cdk_aws_route53recoverycontrol_CfnSafetyRule_GatingRuleProperty, _aws_cdk_aws_route53recoverycontrol_CfnSafetyRule_RuleConfigProperty };
+module.exports = { print, _aws_cdk_aws_route53recoverycontrol_CfnRoutingControlProps, _aws_cdk_aws_route53recoverycontrol_CfnClusterProps, _aws_cdk_aws_route53recoverycontrol_CfnControlPanelProps, _aws_cdk_aws_route53recoverycontrol_CfnRoutingControl, _aws_cdk_aws_route53recoverycontrol_CfnCluster, _aws_cdk_aws_route53recoverycontrol_CfnCluster_ClusterEndpointProperty, _aws_cdk_aws_route53recoverycontrol_CfnControlPanel, _aws_cdk_aws_route53recoverycontrol_CfnSafetyRuleProps, _aws_cdk_aws_route53recoverycontrol_CfnSafetyRule, _aws_cdk_aws_route53recoverycontrol_CfnSafetyRule_AssertionRuleProperty, _aws_cdk_aws_route53recoverycontrol_CfnSafetyRule_GatingRuleProperty, _aws_cdk_aws_route53recoverycontrol_CfnSafetyRule_RuleConfigProperty };
 module.exports.DeprecationError = DeprecationError;
